@@ -85,7 +85,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         Insight.__init__(self, self._env, self._token)
         Channel.__init__(self, self._env, self._token, self._agentId, self._domain)
         Catalog.__init__(self, self._env, self._token)
-        Dataset.__init__(self, self._env, self._token, self._agentId)
+        #Dataset.__init__(self, self._env, self._token, self._agentId)
 
     def __str__(self):
         return '{}'.format(self._agentId)
